@@ -3,32 +3,28 @@ from pathlib import Path
 
 import pytest
 
-from kicad_lib_manager.library_manager import (
-    add_entries_to_table,
-    add_libraries,
-    format_uri,
-)
+from kicad_lib_manager.services.library_service import LibraryService
 
 
 def test_format_uri_absolute_path():
     """Test URI formatting with absolute paths."""
     # Test Unix-style paths
     assert (
-        format_uri("/path/to/lib", "test_lib", "symbols")
+        LibraryService.format_uri("/path/to/lib", "test_lib", "symbols")
         == "/path/to/lib/symbols/test_lib.kicad_sym"
     )
     assert (
-        format_uri("/path/to/lib", "test_lib", "footprints")
+        LibraryService.format_uri("/path/to/lib", "test_lib", "footprints")
         == "/path/to/lib/footprints/test_lib.pretty"
     )
 
     # Test Windows-style paths
     assert (
-        format_uri("C:\\path\\to\\lib", "test_lib", "symbols")
+        LibraryService.format_uri("C:\\path\\to\\lib", "test_lib", "symbols")
         == "C:/path/to/lib/symbols/test_lib.kicad_sym"
     )
     assert (
-        format_uri("C:\\path\\to\\lib", "test_lib", "footprints")
+        LibraryService.format_uri("C:\\path\\to\\lib", "test_lib", "footprints")
         == "C:/path/to/lib/footprints/test_lib.pretty"
     )
 
@@ -36,11 +32,11 @@ def test_format_uri_absolute_path():
 def test_format_uri_env_var():
     """Test URI formatting with environment variable names."""
     assert (
-        format_uri("KICAD_LIB", "test_lib", "symbols")
+        LibraryService.format_uri("KICAD_LIB", "test_lib", "symbols")
         == "${KICAD_LIB}/symbols/test_lib.kicad_sym"
     )
     assert (
-        format_uri("KICAD_LIB", "test_lib", "footprints")
+        LibraryService.format_uri("KICAD_LIB", "test_lib", "footprints")
         == "${KICAD_LIB}/footprints/test_lib.pretty"
     )
 
@@ -49,13 +45,13 @@ def test_format_uri_path_in_curly():
     """Test URI formatting with paths already in ${} format."""
     # Test absolute paths in ${}
     assert (
-        format_uri("${/path/to/lib}", "test_lib", "symbols")
+        LibraryService.format_uri("${/path/to/lib}", "test_lib", "symbols")
         == "/path/to/lib/symbols/test_lib.kicad_sym"
     )
 
     # Test environment variables in ${}
     assert (
-        format_uri("${KICAD_LIB}", "test_lib", "symbols")
+        LibraryService.format_uri("${KICAD_LIB}", "test_lib", "symbols")
         == "${KICAD_LIB}/symbols/test_lib.kicad_sym"
     )
 
@@ -64,30 +60,31 @@ def test_format_uri_edge_cases():
     """Test URI formatting with edge cases."""
     # Test with empty library name
     assert (
-        format_uri("/path/to/lib", "", "symbols") == "/path/to/lib/symbols/.kicad_sym"
+        LibraryService.format_uri("/path/to/lib", "", "symbols")
+        == "/path/to/lib/symbols/.kicad_sym"
     )
 
     # Test with special characters in library name
     assert (
-        format_uri("/path/to/lib", "test-lib_123", "symbols")
+        LibraryService.format_uri("/path/to/lib", "test-lib_123", "symbols")
         == "/path/to/lib/symbols/test-lib_123.kicad_sym"
     )
 
     # Test with mixed slashes
     assert (
-        format_uri("C:/path\\to/lib", "test_lib", "symbols")
+        LibraryService.format_uri("C:/path\\to/lib", "test_lib", "symbols")
         == "C:/path/to/lib/symbols/test_lib.kicad_sym"
     )
 
     # Test with UTF-8 characters in path
     assert (
-        format_uri("/path/to/šžć", "test_lib", "symbols")
+        LibraryService.format_uri("/path/to/šžć", "test_lib", "symbols")
         == "/path/to/šžć/symbols/test_lib.kicad_sym"
     )
 
     # Test with UTF-8 characters and spaces in path
     assert (
-        format_uri("/path/to /šžć ", "test_lib", "symbols")
+        LibraryService.format_uri("/path/to /šžć ", "test_lib", "symbols")
         == "/path/to /šžć /symbols/test_lib.kicad_sym"
     )
 
@@ -95,13 +92,15 @@ def test_format_uri_edge_cases():
 def test_format_uri_invalid_input():
     """Test URI formatting with invalid inputs."""
     with pytest.raises(ValueError):
-        format_uri("", "test_lib", "symbols")  # Empty base path
+        LibraryService.format_uri("", "test_lib", "symbols")  # Empty base path
 
     with pytest.raises(ValueError):
-        format_uri("/path/to/lib", "test_lib", "invalid_type")  # Invalid library type
+        LibraryService.format_uri(
+            "/path/to/lib", "test_lib", "invalid_type"
+        )  # Invalid library type
 
     with pytest.raises(ValueError):
-        format_uri("${unclosed", "test_lib", "symbols")  # Unclosed ${
+        LibraryService.format_uri("${unclosed", "test_lib", "symbols")  # Unclosed ${
 
 
 def test_add_libraries_integration(tmp_path):
@@ -118,20 +117,23 @@ def test_add_libraries_integration(tmp_path):
     (lib_dir / "symbols" / "test_lib.kicad_sym").touch()
     (lib_dir / "footprints" / "test_lib.pretty").touch()
 
+    # Create LibraryService instance
+    service = LibraryService()
+
     # Test with absolute path
-    added_libs, changes = add_libraries(str(lib_dir), config_dir, dry_run=True)
+    added_libs, changes = service.add_libraries(str(lib_dir), config_dir, dry_run=True)
     assert "test_lib" in added_libs
     assert changes
 
     # Test with environment variable path - we need to set up the environment variable first
     os.environ["KICAD_LIB"] = str(lib_dir)
-    added_libs, changes = add_libraries("KICAD_LIB", config_dir, dry_run=True)
+    added_libs, changes = service.add_libraries("KICAD_LIB", config_dir, dry_run=True)
     assert "test_lib" in added_libs
     assert changes
 
     # Test with path in ${} - use a proper environment variable name
     os.environ["TEST_LIB"] = str(lib_dir)
-    added_libs, changes = add_libraries("${TEST_LIB}", config_dir, dry_run=True)
+    added_libs, changes = service.add_libraries("${TEST_LIB}", config_dir, dry_run=True)
     assert "test_lib" in added_libs
     assert changes
 
@@ -152,8 +154,11 @@ def test_add_libraries_utf8(tmp_path):
         lib_dir / "footprints" / "test_šž.pretty"
     ).mkdir()  # Footprint libs are directories
 
+    # Create LibraryService instance
+    service = LibraryService()
+
     # Test adding libraries with UTF-8 paths/names
-    added_libs, changes = add_libraries(str(lib_dir), config_dir, dry_run=True)
+    added_libs, changes = service.add_libraries(str(lib_dir), config_dir, dry_run=True)
 
     # Assert that the libraries with UTF-8 names were detected
     assert "test_čš" in added_libs
@@ -185,7 +190,7 @@ def test_add_entries_with_special_chars(tmp_path):
     ]
 
     # Add entries
-    add_entries_to_table(table_path, entries)
+    LibraryService.add_entries_to_table(table_path, entries)
 
     # Read the updated table
     with Path(table_path).open(encoding="utf-8") as f:
